# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-10-25 13:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ShortURL',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('surl', models.CharField(blank=True, db_index=True, help_text='\u77ed\u94fe', max_length=32, null=True, unique=True, verbose_name='surl')),
                ('lurl', models.CharField(blank=True, db_index=True, help_text='\u957f\u94fe', max_length=255, null=True, unique=True, verbose_name='lurl')),
                ('status', models.BooleanField(db_index=True, default=True, help_text='\u662f\u5426\u663e\u793a', verbose_name='status')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='\u521b\u5efa\u65f6\u95f4', verbose_name='created_at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='\u66f4\u65b0\u65f6\u95f4', verbose_name='updated_at')),
            ],
            options={
                'verbose_name': 'shorturl',
                'verbose_name_plural': 'shorturl',
            },
        ),
    ]
