# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2018-01-07 14:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_short_url', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shorturl',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, help_text='Create Time', verbose_name='created_at'),
        ),
        migrations.AlterField(
            model_name='shorturl',
            name='status',
            field=models.BooleanField(db_index=True, default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='shorturl',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, help_text='Update Time', verbose_name='updated_at'),
        ),
    ]
